#
# spec file for package rzsz
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define realver 0.12.21rc
Name:           rzsz
Version:        0.12.21~rc
Release:        4.9
Summary:        X-, Y-, and Z-Modem Data Transfer Protocols
License:        GPL-2.0-or-later
Group:          Hardware/Modem
URL:            http://www.ohse.de/uwe/software/lrzsz.html
Source:         http://www.ohse.de/uwe/testing/lrzsz-%{realver}.tar.gz
Patch1:         lrzsz-po.patch
Patch2:         lrzsz-0.12.20-use-after-free.patch
Patch4:         lrzsz-autotools.patch
Patch5:         lrzsz-implicit-decl.patch
Patch6:         lrzsz-0.12.20-automake-1.12.patch
Patch7:         lrzsz-0.12.20-automake-1.13.patch
Patch8:         lrzsz-0.12.20-null-pointer.patch
# PATCH-FIX-UPSTREAM fix getopt optstring boo#1076576
Patch9:         lrzsz-0.12.20-fix-lsz-getopt.patch
Patch10:        lrzsz-0.12.21rc-drop-po-intl.patch
BuildRequires:  autoconf
BuildRequires:  automake
Provides:       lrzsz

%description
rzsz allows you to use "sz filename" to send a file to your local
system.

%prep
%setup -q -n lrzsz-%{realver}
%patch1
%patch2 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1

# Missing file
>> config.rpath
# Too old
rm -f missing
# Broken header
rm -f acconfig.h

%build
autoreconf -fvi
%configure
make %{?_smp_mflags}
# generate translation
msgfmt -o po/de.mo po/de.po

%install
%make_install

# install translation
mkdir -p "%{buildroot}/%{_datarootdir}/locale/de/LC_MESSAGES"
cp po/de.mo "%{buildroot}/%{_datarootdir}/locale/de/LC_MESSAGES/lrzsz.mo"
%find_lang lrzsz

# Fix various symlinks
for x in {r,s}{b,x,z} ; do
    pushd "%{buildroot}/%{_bindir}"
    ln -s l$x $x
    popd
    pushd "%{buildroot}/%{_mandir}/man1"
    ln -s l${x:0:1}z.1 ${x}.1
    popd
done

%check
%ifarch ppc64 s390x
make vcheck -j1 || echo "Warning: ignore ZMODEMtcp* tests failure for %{_arch}";
%else
make vcheck -j1
%endif

%files -f lrzsz.lang
%{_mandir}/man1/*
%license COPYING
%doc README.* ABOUT-NLS AUTHORS COMPATABILITY ChangeLog NEWS THANKS TODO
%{_bindir}/rb
%{_bindir}/rx
%{_bindir}/rz
%{_bindir}/sb
%{_bindir}/sx
%{_bindir}/sz
%{_bindir}/lrb
%{_bindir}/lrx
%{_bindir}/lrz
%{_bindir}/lsb
%{_bindir}/lsx
%{_bindir}/lsz

%changelog
* Tue Jul  9 2019 Benoît Monin <benoit.monin@gmx.fr>
- add lrzsz-0.12.21rc-drop-po-intl.patch (bsc#1181571):
  fix build with gettext >= 0.20
- generate and install translation file manually
* Thu Apr  5 2018 tchvatal@suse.com
- Update to 0.12.21~rc bsc#1086416 bsc#1090051 CVE-2018-10195:
  * RC candidate from 1999 containing bunch of trivial fxies that
    most other distributions ship
- Rebase patches:
  * lrzsz-0.12.20-automake-1.13.patch
  * lrzsz-autotools.patch
  * lrzsz-po.patch
* Sun Jan 21 2018 benoit.monin@gmx.fr
- add lrzsz-0.12.20-fix-lsz-getopt.patch: fix for boo#1076576
* Thu Jan 18 2018 tchvatal@suse.com
- Run spec-cleaner
* Sun Sep  3 2017 benoit.monin@gmx.fr
- remove _link to factory to build the package in the devel project
- change source to tar.gz: upstream does not provide tar.bz2
- also ignore ZMODEMtcp* tests failure for s390x
* Thu Apr 14 2016 normand@linux.vnet.ibm.com
- ignore ZMODEMtcp* tests failure for ppc64 archi
* Mon Aug  4 2014 ro@suse.de
- re-diff lrzsz-implicit-decl.patch
- Drop unused drop_ftime.patch
* Mon May 12 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Apply autoconf patches to allow autoreconf:
  * lrzsz-autotools.patch
  * lrzsz-0.12.20-automake-1.12.patch
  * lrzsz-0.12.20-automake-1.13.patch
- Fix compilation with latest gccs:
  * lrzsz-implicit-decl.patch
- Fix null as last argument for function calls:
  * lrzsz-0.12.20-null-pointer.patch
- Remove weirdly done patch that merged multiple operations at once:
  * lrzsz-0.12.20.dif
- Run test phase
- Run make install properly and create symlinks for the
  other binaries to provide lrz* to r* symlinks and thus match other
  distributions.
* Thu Nov 14 2013 dvaleev@suse.com
- Drop obsoleted ftime. (drop_ftime.patch)
  Broken under PowerKVM
* Fri Sep 30 2011 uli@suse.com
- cross-build fixes: use %%configure macro, install to correct bindir
* Mon Sep  7 2009 mmarek@suse.cz
- lrzsz-0.12.20-use-after-free.patch: fix for bnc#529899.
* Mon Feb 25 2008 crrodriguez@suse.de
- use find_lang macro
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jun 17 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Mon Jan 24 2005 meissner@suse.de
- fixed some implicit warnings, fixed one execle.
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu Aug 22 2002 nadvornik@suse.cz
- installed /usr/bin/sx again (sx from package sp was renamed)
* Mon Jan 22 2001 nadvornik@suse.cz
- fixed typo in german po file
* Mon Oct  9 2000 nadvornik@suse.cz
- fixed Copyright
- used bzip2
* Thu Apr 20 2000 nadvornik@suse.cz
- added BuildRoot
- added URL
- removed Makefile.Linux
* Thu Mar  2 2000 zoz@suse.de
- /usr/man -> /usr/share/man
* Fri Oct  1 1999 zoz@suse.de
- manpage sx removed, added remark to man sz
- added README.SuSE with same remark
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Mar  1 1999 ro@suse.de
- don't redeclare strstr if already defined as a macro
* Wed Jan 20 1999 bs@suse.de
- removed /usr/bin/sx from file list (is in package sp)
* Tue Jan 19 1999 florian@suse.de
- update to lrzsz 0.12.20
- fixed list of files
* Sun Sep 27 1998 ro@suse.de
- define DST_NONE if undefined
* Thu Oct 23 1997 ro@suse.de
- ready for autobuild
  update to new version lrzsz 0.12b
